        function getT(rr,cc){
       if(rr==7 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260526 a 12</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==7 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260526 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>49</strong> miembros: 24 <strong>control</strong><br>0,2,4,5,8,9,10,14,15,17,19,20,21,22,23,25,29,35,40,41,45,48,49,50';}
       if(rr==7 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260526 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>24</strong> miembros: 20 <br>1,6,12,13,16,24,26,27,28,30,32,33,34,36,37,39,42,43,44,46';}
       if(rr==7 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260526 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>31</strong> miembros: 7 <br>3,7,11,18,31,38,47';}
       if(rr==34 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260526 a 12</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==34 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260526 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>49</strong> miembros: 24 <strong>control</strong><br>0,2,4,5,8,9,10,14,15,17,19,20,21,22,23,25,29,35,40,41,45,48,49,50';}
       if(rr==34 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260526 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>24</strong> miembros: 20 <br>1,6,12,13,16,24,26,27,28,30,32,33,34,36,37,39,42,43,44,46';}
       if(rr==34 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260526 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>31</strong> miembros: 7 <br>3,7,11,18,31,38,47';}
       if(rr==35 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260526 a 12</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==35 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260526 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>49</strong> miembros: 24 <strong>control</strong><br>0,2,4,5,8,9,10,14,15,17,19,20,21,22,23,25,29,35,40,41,45,48,49,50';}
       if(rr==35 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260526 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>24</strong> miembros: 20 <br>1,6,12,13,16,24,26,27,28,30,32,33,34,36,37,39,42,43,44,46';}
       if(rr==35 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260526 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>31</strong> miembros: 7 <br>3,7,11,18,31,38,47';}
       if(rr==36 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260526 a 12</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==36 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260526 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>49</strong> miembros: 24 <strong>control</strong><br>0,2,4,5,8,9,10,14,15,17,19,20,21,22,23,25,29,35,40,41,45,48,49,50';}
       if(rr==36 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260526 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>24</strong> miembros: 20 <br>1,6,12,13,16,24,26,27,28,30,32,33,34,36,37,39,42,43,44,46';}
       if(rr==36 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260526 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>31</strong> miembros: 7 <br>3,7,11,18,31,38,47';}
       if(rr==37 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260526 a 12</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==37 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260526 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>49</strong> miembros: 24 <strong>control</strong><br>0,2,4,5,8,9,10,14,15,17,19,20,21,22,23,25,29,35,40,41,45,48,49,50';}
       if(rr==37 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260526 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>24</strong> miembros: 20 <br>1,6,12,13,16,24,26,27,28,30,32,33,34,36,37,39,42,43,44,46';}
       if(rr==37 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260526 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>31</strong> miembros: 7 <br>3,7,11,18,31,38,47';}
       if(rr==38 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260526 a 12</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==38 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260526 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>49</strong> miembros: 24 <strong>control</strong><br>0,2,4,5,8,9,10,14,15,17,19,20,21,22,23,25,29,35,40,41,45,48,49,50';}
       if(rr==38 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260526 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>24</strong> miembros: 20 <br>1,6,12,13,16,24,26,27,28,30,32,33,34,36,37,39,42,43,44,46';}
       if(rr==38 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260526 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>31</strong> miembros: 7 <br>3,7,11,18,31,38,47';}
       if(rr==39 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260526 a 12</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==39 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260526 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>49</strong> miembros: 24 <strong>control</strong><br>0,2,4,5,8,9,10,14,15,17,19,20,21,22,23,25,29,35,40,41,45,48,49,50';}
       if(rr==39 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260526 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>24</strong> miembros: 20 <br>1,6,12,13,16,24,26,27,28,30,32,33,34,36,37,39,42,43,44,46';}
       if(rr==39 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260526 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>31</strong> miembros: 7 <br>3,7,11,18,31,38,47';}
}
