        function getT(rr,cc){
       if(rr==2 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260526 a 12</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==2 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260526 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>49</strong> miembros: 24 <strong>control</strong><br>0,2,4,5,8,9,10,14,15,17,19,20,21,22,23,25,29,35,40,41,45,48,49,50';}
       if(rr==2 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260526 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>24</strong> miembros: 20 <br>1,6,12,13,16,24,26,27,28,30,32,33,34,36,37,39,42,43,44,46';}
       if(rr==2 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260526 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>31</strong> miembros: 7 <br>3,7,11,18,31,38,47';}
       if(rr==9 && cc==0){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260526 a 12</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==9 && cc==1){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260526 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>49</strong> miembros: 24 <strong>control</strong><br>0,2,4,5,8,9,10,14,15,17,19,20,21,22,23,25,29,35,40,41,45,48,49,50';}
       if(rr==9 && cc==2){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260526 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>24</strong> miembros: 20 <br>1,6,12,13,16,24,26,27,28,30,32,33,34,36,37,39,42,43,44,46';}
       if(rr==9 && cc==3){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260526 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>31</strong> miembros: 7 <br>3,7,11,18,31,38,47';}
       if(rr==10 && cc==0){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260526 a 12</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==10 && cc==1){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260526 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>49</strong> miembros: 24 <strong>control</strong><br>0,2,4,5,8,9,10,14,15,17,19,20,21,22,23,25,29,35,40,41,45,48,49,50';}
       if(rr==10 && cc==2){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260526 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>24</strong> miembros: 20 <br>1,6,12,13,16,24,26,27,28,30,32,33,34,36,37,39,42,43,44,46';}
       if(rr==10 && cc==3){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260526 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>31</strong> miembros: 7 <br>3,7,11,18,31,38,47';}
       if(rr==11 && cc==0){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260526 a 12</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==11 && cc==1){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260526 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>49</strong> miembros: 24 <strong>control</strong><br>0,2,4,5,8,9,10,14,15,17,19,20,21,22,23,25,29,35,40,41,45,48,49,50';}
       if(rr==11 && cc==2){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260526 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>24</strong> miembros: 20 <br>1,6,12,13,16,24,26,27,28,30,32,33,34,36,37,39,42,43,44,46';}
       if(rr==11 && cc==3){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260526 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>31</strong> miembros: 7 <br>3,7,11,18,31,38,47';}
       if(rr==12 && cc==0){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260526 a 12</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==12 && cc==1){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260526 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>49</strong> miembros: 24 <strong>control</strong><br>0,2,4,5,8,9,10,14,15,17,19,20,21,22,23,25,29,35,40,41,45,48,49,50';}
       if(rr==12 && cc==2){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260526 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>24</strong> miembros: 20 <br>1,6,12,13,16,24,26,27,28,30,32,33,34,36,37,39,42,43,44,46';}
       if(rr==12 && cc==3){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260526 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>31</strong> miembros: 7 <br>3,7,11,18,31,38,47';}
       if(rr==13 && cc==0){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260526 a 12</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==13 && cc==1){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260526 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>49</strong> miembros: 24 <strong>control</strong><br>0,2,4,5,8,9,10,14,15,17,19,20,21,22,23,25,29,35,40,41,45,48,49,50';}
       if(rr==13 && cc==2){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260526 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>24</strong> miembros: 20 <br>1,6,12,13,16,24,26,27,28,30,32,33,34,36,37,39,42,43,44,46';}
       if(rr==13 && cc==3){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260526 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>31</strong> miembros: 7 <br>3,7,11,18,31,38,47';}
       if(rr==14 && cc==0){return '<strong>Precipitacion de 00 a 12 UTC (mm)</strong><br><br><strong>20260526 a 12</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==14 && cc==1){return '<strong>Precipitacion de 00 a 12 UTC (mm)</strong><br><br><strong>20260526 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>49</strong> miembros: 24 <strong>control</strong><br>0,2,4,5,8,9,10,14,15,17,19,20,21,22,23,25,29,35,40,41,45,48,49,50';}
       if(rr==14 && cc==2){return '<strong>Precipitacion de 00 a 12 UTC (mm)</strong><br><br><strong>20260526 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>24</strong> miembros: 20 <br>1,6,12,13,16,24,26,27,28,30,32,33,34,36,37,39,42,43,44,46';}
       if(rr==14 && cc==3){return '<strong>Precipitacion de 00 a 12 UTC (mm)</strong><br><br><strong>20260526 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>31</strong> miembros: 7 <br>3,7,11,18,31,38,47';}
       if(rr==15 && cc==0){return '<strong>Nieve acumulada de 00 a 12 UTC (mm de agua equivalente)</strong><br><br><strong>20260526 a 12</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==15 && cc==1){return '<strong>Nieve acumulada de 00 a 12 UTC (mm de agua equivalente)</strong><br><br><strong>20260526 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>49</strong> miembros: 24 <strong>control</strong><br>0,2,4,5,8,9,10,14,15,17,19,20,21,22,23,25,29,35,40,41,45,48,49,50';}
       if(rr==15 && cc==2){return '<strong>Nieve acumulada de 00 a 12 UTC (mm de agua equivalente)</strong><br><br><strong>20260526 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>24</strong> miembros: 20 <br>1,6,12,13,16,24,26,27,28,30,32,33,34,36,37,39,42,43,44,46';}
       if(rr==15 && cc==3){return '<strong>Nieve acumulada de 00 a 12 UTC (mm de agua equivalente)</strong><br><br><strong>20260526 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>31</strong> miembros: 7 <br>3,7,11,18,31,38,47';}
       if(rr==16 && cc==0){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260526 a 12</strong> UTC HH+042 (rango:036-048)<br><strong>control +<br>EPS</strong>';}
       if(rr==16 && cc==1){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260526 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>1</strong> representante: <strong>49</strong> miembros: 24 <strong>control</strong><br>0,2,4,5,8,9,10,14,15,17,19,20,21,22,23,25,29,35,40,41,45,48,49,50';}
       if(rr==16 && cc==2){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260526 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>2</strong> representante: <strong>24</strong> miembros: 20 <br>1,6,12,13,16,24,26,27,28,30,32,33,34,36,37,39,42,43,44,46';}
       if(rr==16 && cc==3){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260526 a 12</strong> UTC HH+042 (rango:036-048)<br>grupo: <strong>3</strong> representante: <strong>31</strong> miembros: 7 <br>3,7,11,18,31,38,47';}
}
